@@ -60,9 +60,10 @@ SAMPLE OUTPUT
 {'full_text': 'up 1 days 18 hours 20 minutes'}
 """
 
-from time import time
+import time
 from datetime import datetime
 from collections import OrderedDict
+from pathlib import Path
 
 
 class Py3status:
@@ -91,9 +92,9 @@ class Py3status:
                 self.seconds, self.interval = None, second
 
     def uptime(self):
-        with open("/proc/uptime") as f:
+        with Path("/proc/uptime").open() as f:
             up = int(float(f.readline().split()[0]))
-            offset = time() - up
+            offset = time.time() - up
 
         uptime = {}
         for unit, interval in self.time_periods.items():
